#
# spec file for package unrar
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# majorversion should match the major version number.
%define majorversion 7
%define libsuffix 7_0_7
Name:           unrar
Version:        7.0.7
Release:        1.4
Summary:        A program to extract, test, and view RAR archives
License:        NonFree
URL:            https://www.rarlab.com
Source0:        https://www.rarlab.com/rar/%{name}src-%{version}.tar.gz
Source1:        unrar.1
Source99:       baselibs.conf
Patch1:         soname.patch
BuildRequires:  gcc-c++
%{?suse_build_hwcaps_libs}

%description
The unRAR utility is a freeware program distributed with source code
and developed for extracting, testing, and viewing the contents of
archives created with the RAR archiver.

%package -n libunrar%{libsuffix}
Summary:        Decompress library for RAR archives
Group:          System/Libraries

%description -n libunrar%{libsuffix}
The libunrar library allows programs linking against it to decompress
existing RAR v3 archives.

%package -n libunrar-devel
Summary:        Development files for libunrar
Group:          Development/Libraries/C and C++
Requires:       libunrar%{libsuffix} = %{version}

%description -n libunrar-devel
The libunrar-devel package contains libraries and header files for
developing applications that use libunrar.

%prep
%autosetup -n %{name} -p1

sed -i 's/\r$//' *.txt

%build
%make_build -f makefile unrar lib libversion=%{version} CXXFLAGS="%{optflags} -fPIC -fno-strict-aliasing" STRIP=true

%install
install -Dpm 0755 unrar \
  %{buildroot}%{_bindir}/unrar
install -Dpm 0644 %{SOURCE1} \
  %{buildroot}%{_mandir}/man1/unrar.1
install -Dpm 0755 libunrar.so.%{version} \
    %{buildroot}%{_libdir}/libunrar.so.%{version}
install -Dpm 0644 dll.hpp \
  %{buildroot}/%{_includedir}/unrar/dll.hpp
ln -s libunrar.so.%{version} \
    %{buildroot}%{_libdir}/libunrar.so

%post -n libunrar%{libsuffix} -p /sbin/ldconfig
%postun -n libunrar%{libsuffix} -p /sbin/ldconfig

%files
%license license.txt
%doc acknow.txt readme.txt
%{_bindir}/unrar
%{_mandir}/man1/unrar.1%{?ext_man}

%files -n libunrar%{libsuffix}
%license license.txt
%{_libdir}/*.so.%{version}

%files -n libunrar-devel
%license license.txt
%doc acknow.txt readme.txt
%{_includedir}/*
%{_libdir}/*.so

%changelog
* Sun Mar 10 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 7.0.7:
  * No upstream changelog available
* Fri Feb  2 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 7.0.6:
  * No upstream changelog available
* Sat Oct 21 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 6.2.12
  * No upstream changelog available
* Thu Aug 17 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 6.2.10
  * No upstream changelog available
* Thu Jun 22 2023 Pablo Herranz Ramírez <pablo.herranz@suse.com>
- Update to version 6.2.8
  * No upstream changelog available
* Wed Mar  8 2023 Martin Pluskal <mpluskal@suse.com>
- Build AVX2 enabled hwcaps library for x86_64-v3
* Tue Feb  7 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 6.2.5:
  * no upstream changelog available
* Thu Nov 24 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 6.2.2:
  * Based on final RAR 6.22
* Sat May  7 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 6.1.7:
  * Based on final RAR 6.12
* Thu Mar 24 2022 Dirk Müller <dmueller@suse.com>
- update to 6.1.6:
  * Based on final RAR 6.11
* Fri Jan 28 2022 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 6.1.4.
  * Based on final RAR 6.10.
  * Switch -si can be used when extracting or testing to read archive
    data from stdin.
  * New -ep4<path> switch excludes the path prefix when extracting if
    this path is found in the beginning of archived name.
  * New -mes switch skips encrypted files when extracting or testing.
    It replaces former -p- switch.
  * New -op<path> switch sets the destination directory for 'x' and 'e'
    extraction commands.
  * If 'p' command is used to print a file to stdout, informational
    messages are suppressed automatically to prevent them mixing
    with file date.
  * Warning is issued if entered password exceeds the allowed limit
    of 127 characters and is truncated. Previously such passwords
    had been truncated silently.
* Sat Dec 11 2021 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 6.1.3:
  * no upstream changelog available
* Mon Jun 14 2021 Ismail Dönmez <ismail@i10z.com>
- Update to version 6.0.7
  * Based on WinRAR 6.0.2
* Tue May 18 2021 Ismail Dönmez <ismail@i10z.com>
- Update to version 6.0.6
  * Based on WinRAR 6.02 beta 1
* Tue Apr 13 2021 Ismail Dönmez <idonmez@suse.com>
- Update to version 6.0.5
  * Based on WinRAR 6.0.1
* Fri Mar  5 2021 Ismail Dönmez <idonmez@suse.com>
- Update to version 6.0.4
  * Based on WinRAR 6.0.1 beta 1
* Mon Dec  7 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 6.0.3
  * Based on WinRAR 6.00
* Thu Nov 12 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 6.0.2
  * Based on WinRAR 6.00 beta 2
* Thu Oct 22 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 6.0.1
  * Based on WinRAR 6.00 beta 1
* Thu Jul 16 2020 Martin Pluskal <mpluskal@suse.com>
- Use https for urls
* Mon Jun 29 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.9.4
  * Based on WinRAR version 5.91 final
* Sat Jun  6 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.9.3
  * Based on WinRAR version 5.91 beta 1
- Refresh and rename unrarsrc-5.0.5-soname.patch to soname.patch
* Tue Mar 31 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.9.2
  * Based on WinRAR version 5.90 final
* Wed Jan 29 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.9.1
  * Based on WinRAR version 5.90 beta1
* Wed Dec 11 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.8.5
  * Based on WinRAR version 5.80 final
* Sun Nov 17 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.8.4
  * Based on WinRAR version 5.80 beta 4
* Sun Oct 20 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.8.3
  * Based on WinRAR version 5.80 beta 3
* Fri Sep 27 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.8.2
  * Based on WinRAR version 5.80 beta 2
* Fri Aug 30 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.8.1
  * Based on WinRAR version 5.80 beta 1
* Mon Apr 29 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.7.5
  * No upstream changelog
* Sun Apr  7 2019 seanlew@opensuse.org
- Update to version 5.7.4
  * No upstream changelog
* Mon Mar 11 2019 Kyrill Detinov <lazy.kent@opensuse.org>
- Update the manual page.
* Thu Feb 28 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.7.3
  * Based on WinRAR 5.70
  * No upstream changelog
* Thu Feb 21 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.7.2
  * No upstream changelog
* Wed Jan 30 2019 info@paolostivanin.com
- Update to 5.7.1
  * No upstream changelog
* Fri Oct 12 2018 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 5.6.8.
  * Based on final RAR 5.61.
  * Fixed a crash when processing corrupt RAR archives. This issue
    may be also associated with security risks.
* Tue Oct  2 2018 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.6.7
  * No upstream changelog
* Tue Jun 26 2018 idonmez@suse.com
- Update to version 5.6.5
  * No upstream changelog
* Mon Jun  4 2018 idonmez@suse.com
- Update to version 5.6.4
  * No upstream changelog
* Tue Apr 24 2018 idonmez@suse.com
- Update to version 5.6.3
  * No upstream changelog
* Fri Apr 13 2018 mpluskal@suse.com
- Cleanup spec file with spec-clener
* Tue Apr  3 2018 idonmez@suse.com
- Update to version 5.6.2
  * No upstream changelog
* Tue Mar 20 2018 kstreitova@suse.com
- the following issues are completely fixed in the current unrar
  release [bsc#1054038]:
  * UnRAR before 5.5.7 allows remote attackers to bypass a
    directory-traversal protection mechanism via vectors involving
    a symlink to the . directory, a symlink to the .. directory,
    and a regular file [CVE-2017-12938]
  * UnRAR before 5.5.7 has an out-of-bounds read in
    the EncodeFileName::Decode call within the
    Archive::ReadHeader15 function [CVE-2017-12940]
  * UnRAR before 5.5.7 has an out-of-bounds read in
    the Unpack::Unpack20 function [CVE-2017-12941]
  * UnRAR before 5.5.7 has a buffer overflow in the Unpack::LongLZ
    function [CVE-2017-12942]
- it also fixes conditional jumps mentioned in [bsc#1046882]
* Mon Mar 12 2018 mvetter@suse.com
- Update to 5.6.1:
  * No upstream changelog
* Mon Aug 14 2017 idonmez@suse.com
- Update to version 5.5.8
  * Based on rar 5.50 release
* Mon Jul 31 2017 idonmez@suse.com
- Update to version 5.5.7
  * "Checksum error" could be mistakenly reported for some valid
    GZIP archives.
* Mon Jul  3 2017 idonmez@suse.com
- Update to version 5.5.6
  * No changelog upstream
* Wed Jun 21 2017 sebix+novell.com@sebix.at
- Update to version 5.5.5
  * fixes VMSF_DELTA memory corruption (boo#1045315) CVE-2012-6706
    see https://bugs.chromium.org/p/project-zero/issues/detail?id=1286&can=1&q=unrar&desc=2
* Mon Jun 12 2017 idonmez@suse.com
- Update to version 5.5.4
  * No changelog upstream.
* Mon May  1 2017 idonmez@suse.com
- Update to version 5.5.1
  * Based on RAR 5.50 beta1
  * Added extraction support for .LZ archives created by Lzip
    compressor.
  * Modern TAR tools can store high precision file times, lengthy
    file names and large file sizes in special PAX extended headers
    inside of TAR archive. Now WinRAR supports such PAX headers
    and uses them when extracting TAR archives.
  * unrar no longer fails to unpack files in ZIP archives compressed
    with XZ algorithm and encrypted with AES
- Remove unrarsrc-3.9-types.patch, fixed upstream.
* Thu Aug 18 2016 lazy.kent@opensuse.org
- Update to 5.4.5.
  * Based on final RAR 5.40.
  * If RAR recovery volumes (.rev files) are present in the same
    folder as usual RAR volumes, archive test command verifies .rev
    contents after completing testing .rar files.
    If you wish to test only .rev files without checking .rar
    volumes, you can run: `unrar t arcname.part1.rev`.
  * If -p switch is used without optional <pwd> parameter, a
    password can be also set with file redirection or pipe.
  * unrar treats 'arcname.partN' as 'arcname.partN.rar' if
    'arcname.partN' does not exist and 'arcname.part#.rar' exists.
    For example, it is allowed to run:
    `unrar x arcname.part01` to start extraction from
    'arcname.part01.rar'.
* Fri Jul 22 2016 mpluskal@suse.com
- Update to version 5.4.3:
  * No changelog provided.
* Tue May 31 2016 mpluskal@suse.com
- Update to version 5.4.2:
  * No changelog provided.
* Wed May 11 2016 mpluskal@suse.com
- Update to 5.4.1:
  * No changelog provided.
* Sat Mar 26 2016 lazy.kent@opensuse.org
- Update to 5.3.11.
  * No changelog.
* Thu Feb  4 2016 idonmez@suse.com
- Update to 5.3.10
  * No changelog upstream.
* Sun Jan 10 2016 lazy.kent@opensuse.org
- Update to 5.3.9.
  * No changelog available.
* Tue Nov 24 2015 idonmez@suse.com
- Update to 5.3.8
  * No changelog upstream
* Wed Oct 28 2015 idonmez@suse.com
- Update to 5.3.7
  * Changes in broken archive processing to handle invalid ZIP,
    ARJ and ISO archives more reliably
* Thu Oct  8 2015 lazy.kent@opensuse.org
- Update to 5.3.5.
  * Fixed bug: unrar could crash when unpacking .rar archives with
    corrupt file headers.
* Mon Sep 14 2015 idonmez@suse.com
- Update to 5.3.4
  * No changelog upstream
* Thu Aug 27 2015 idonmez@suse.com
- Update to 5.3.3
  * No changelog available.
* Tue Aug  4 2015 idonmez@suse.com
- Update to 5.3.2
  * No changelog available.
* Mon Jul 20 2015 idonmez@suse.com
- Update to 5.3.1
  * No changelog available.
* Sun Apr 26 2015 lazy.kent@opensuse.org
- Update to 5.2.7.
  * No changelog available.
* Mon Feb 16 2015 lazy.kent@opensuse.org
- Update to 5.2.6.
  * Based on final rar 5.21.
* Sat Jan 31 2015 lazy.kent@opensuse.org
- Update to 5.2.5.
  * Based on rar 5.21 beta 2.
  * Now by default unrar skips symbolic links with absolute paths
    in link target when extracting. You can enable creating such
    links with -ola command line switch.
    Such links pointing to folders outside of extraction
    destination folder can present a security risk. Enable their
    extraction only if you are sure that archive contents is safe,
    such as your own backup.
- Update a manual page.
* Wed Dec  3 2014 lazy.kent@opensuse.org
- Update to 5.2.3.
  * Based on final rar 5.20.
  * File overwrite prompt displays the size and modification time
    for existing and new files.
  * Warning is issued when starting unpacking 4 GB or larger file
    from RAR archive to FAT32 patition, so user may cancel the
    operation. FAT32 does not support files of such size.
* Mon Nov  3 2014 lazy.kent@opensuse.org
- Update to 5.2.2.
  * Based on rar 5.20 beta 3.
  * No changelog available.
* Tue Oct 14 2014 lazy.kent@opensuse.org
- Update to 5.2.1.
  * Based on rar 5.20 beta 1.
  * File overwrite prompt in unrar displays the size and
    modification time for existing and new files.
* Wed Aug 27 2014 jengelh@inai.de
- Remove libunrar.so.5 symlink, which does not match the SONAME of
  any library and would conflict with another libunrar version.
* Sun Aug 10 2014 lazy.kent@opensuse.org
- Update to 5.1.7.
  * Based on rar 5.11 beta 1.
  * No changelog available.
* Wed Jun 11 2014 lazy.kent@opensuse.org
- Update to 5.1.6.
  * Based on final RAR 5.10.
  * Added support for AES-NI CPU instructions allowing to improve
    RAR decryption performance.
* Wed May  7 2014 lazy.kent@opensuse.org
- Update to 5.1.5.
  * Based on rar 5.10 beta 4.
  * Bugs fixed:
    + beta 3 failed to decompress multivolume encrypted RAR
    archives;
    + under rare conditions x86 version working in multithreaded
    mode on SSE2 enabled CPU could erroneously issue checksum error
    message for first file in valid RAR5 archive with BLAKE2sp
    checksums.
* Sat Apr 26 2014 lazy.kent@opensuse.org
- Update to 5.1.3.
  * Based on rar 5.10 beta 3.
  * More efficient implementation of "Keep broken files" extraction
    option (-kb switch in command line mode). Now it allows to
    recover more data from file split between RAR volumes if next
    volume is missing.
* Sat Apr  5 2014 lazy.kent@opensuse.org
- Update to 5.1.2.
  * Based on rar 5.10 beta 2.
  * Bugs fixed:
    + Unix RAR could not decompress hard links stored by WinRAR if
    link source name included path separator characters.
    + Fixed compilation for PowerPC.
* Thu Mar 20 2014 lazy.kent@opensuse.org
- Update to 5.1.1.
  * Based on rar 5.10 beta 1.
  * No changelog available.
* Thu Dec  5 2013 lazy.kent@opensuse.org
- Update to 5.0.14.
  * Based on final rar 5.01.
  * Bugs fixed:
    + "Test" command could erroneously report damaged data in valid
    recovery record if only a part of files in RAR 5.0 archive
    was tested. It did not happen if entire archive contents was
    tested.
    + "Test" command erroneously reported errors when verifying RAR
    4.x Unix symbolic links.
    + RAR 5.0 'p' (print) command did not display file contents.
* Tue Nov 12 2013 idonmez@suse.com
- Update to 5.0.13
  * No changelog
* Mon Oct 21 2013 idonmez@suse.com
- Update to 5.0.12
  * No changelog
* Tue Sep  3 2013 lazy.kent@opensuse.org
- Update to 5.0.11.
  * Based on final rar 5.0.0.
* Sun Aug  4 2013 lazy.kent@opensuse.org
- Update to 5.0.10.
  * Added missing makefile.
* Sun Aug  4 2013 lazy.kent@opensuse.org
- Update to 5.0.9.
  * No changelog available.
- Add acknow.txt to docs.
- Don't install readme.txt to the libunrar package.
- Temporarily use the makefile file from the previous version
  (missing in the source).
* Sun Jul 14 2013 lazy.kent@opensuse.org
- Update to 5.0.8.
  * No changes announced for unrar.
* Fri Jun 28 2013 idonmez@suse.com
- Update to 5.0.7
  * No changelog available
* Wed Jun 12 2013 idonmez@suse.com
- Update to 5.0.6
  * No changelog available
- Drop unrarsrc-4.2.4-gcc.patch, not needed anymore
* Tue May 28 2013 lazy.kent@opensuse.org
- Update to 5.0.5.
  * Support new RAR 5.0 archiving format.
  * 'v' and 'l' commands display archived file names in the end of
    line, not in that beginning as before. Also some fields
    previously available in 'l' and 'v' output are now shown only
    by 'lt' and 'vt'.
    'vt' and 'lt' commands provide the detailed multiline
    information for every archived file.
    'vta' and 'lta' also include service headers into list.
- Drop unrarsrc-3.9-variablesize.patch and
  unrar-4.2.4-no_return.patch (fixed upstream).
- Update unrarsrc-*-soname.patch.
- Disable unrarsrc-4.2.4-gcc.patch (until anyone confirms we really
  need it).
- Clean up "make" string (remove dupes provided by "optflags"
  macro).
- Correct libunrar Summary (remove v3).
- Update manual page.
* Fri Oct 19 2012 cfarrell@suse.com
- license update: SUSE-NonFree
  The description of SUSE-Permissive on the spreadsheet linked from
  license.opensuse.org would imply that such a licensed software would be
  suitable for Factory. For unrar this is clearly not the case - hence
  SUSE-NonFree
* Fri Oct 12 2012 lazy.kent@opensuse.org
- Update to 4.2.4.
  * No changelog provided.
- Add unrar-4.2.4-no_return.patch: fix no-return-in-nonvoid-function
  error.
- Change License tag: SUSE-Permissive.
- Use full URL as a source.
- Update "unrarsrc-*-gcc" and "unrarsrc-*-soname" patches.
- Correct libunrar Group: System/Libraries.
- Remove Provides: libunrar3_9_10-devel (no dependent packages
  found).
- Update man page.
- Mark man as doc.
- Clean up and formatting spec.
* Mon May 16 2011 puzel@novell.com
- use correct defines for building the library (bnc#693890)
* Wed Jan  5 2011 davejplater@gmail.com
- Update to 4.0.4 and remade updated man page with help2man
- Upstream changes :
  * previous beta versions could truncate some of files,
  extracted from ISO 9660 archives.
  * Version 4.00 beta 3
  * Now switch -ep3 converts not only disk letters, but also UNC paths.
  So \\server\share will be converted to __server\share when archiving
  and restored to the original \\server\share when extracting with -ep3.
  * previous beta could fail to unpack self-extracting and multivolume
  CAB archives;
  * "Create a new folder" command always created new folders
  in the root archive folder;
  * "Remove redundant folders from extraction path" option did not work;
  * previous beta crashed when displaying archive comments
  with ANSI escape sequences;
  * switches -cl and -cu did not work.
  * Version 4.00 beta 2
  * If you enabled "Use for all archives" option when entering the default
  password (Ctrl+P) and specified the empty password, extract and test
  commands will skip all encrypted archives.
  * Version 4.00 beta 1
  * RAR decompression speed is improved. Depending on data type,
  decompression can be up to 30%% faster than in previous versions.
  Both the general RAR algorithm and most of special RAR multimedia
  methods benefit from this improvement. The only module of RAR
  algorithm, which is not affected, is "Text compression" method.
  * UDF support is upgraded to UDF 2.50 revision. It makes possible
  to unpack most of Blu-ray ISO files;
  * Changes in -x switch syntax. Now you can specify a wildcard
  exclusion mask for folders. Such mask must have the trailing '\'
  character, like -x*tmp*\ or -x*\temp\
  * New error code 10 ("no files") is added to list of error codes
  returned in command line mode by RAR and WinRAR. This new code
  can be returned by archive, extract, delete and repair commands.
  It means that RAR did not find any files matched the specified
  file or archive mask.
  * Now switch -ep3 converts not only disk letters, but also UNC paths.
  So \\server\share will be converted to __server\share when archiving
  and restored to the original \\server\share when extracting with -ep3.
  * renaming a file in archive could also rename all other files
  with the same name in other folders of the same archive;
  * previous versions displayed the wrong total packed size
  in "Info" command for multivolume CAB archives;
- See "http://www.rarlab.com/rarnew.htm" for more details
* Wed Aug 18 2010 puzel@novell.com
- update to 3.9.10
  * no changelog available
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Mon Jun 22 2009 mseben@suse.cz
- added libunrar* and libunrar*-devel subpackage bnc#513804
- added man page from debian
- updated to 3.9.4
  * no changelog available
* Thu Jan  8 2009 mseben@suse.cz
- update to 3.8.5
  * no changelog available
* Fri Jul 18 2008 lmichnovic@suse.cz
- update to 3.8.2 beta
  * no changelog available
- obsoletes *strcmp.patch
* Mon Nov 26 2007 lmichnovic@suse.cz
- update to 3.7.8 beta
  * RAR can close a corrupt encrypted archive
  * fix for CVE-2007-3726, obsoletes patch
* Tue Jul 17 2007 lmichnovic@suse.cz
- fix for crash on corrupted file (CVE-2007-3726.patch) [#291702]
* Fri Jun  8 2007 lmichnovic@suse.cz
- update to 3.7.6 final
  * minor code rework
  * fixed CR-LF in file with License
* Mon Mar 12 2007 lmichnovic@suse.cz
- update to version 3.7.4 beta
  * minor code rework
* Fri Feb 23 2007 lmichnovic@suse.cz
- corrected typo in code (variablesize.patch)
* Tue Feb 13 2007 lmichnovic@suse.cz
- update to version 3.7.3 beta
  * rewritten work with memory in VM
* Tue Jan 23 2007 lmichnovic@suse.cz
- update to version 3.7.2 beta
  * Stack overflow vulnerability has been corrected in password
    processing module of console RAR and UnRAR.
  * New switch -sc[objects] allowing to select character sets for
    archive comments and list files. It replaces -fcu switch, which
    was removed from list of supported switches. Now you need to
    specify -scuc instead of -fcu to use Unicode comments.
    Unlike -fcu, -sc also supports OEM and ANSI charset.
  * workaround for one occasional bug with unicode
* Sun Dec 17 2006 schwab@suse.de
- Fix last change.
* Fri Dec 15 2006 lmichnovic@suse.cz
- corrected and readded reverted *strcmp.patch
* Fri Dec 15 2006 mmarek@suse.cz
- revert last change (it worked previously and the strcmp patch
  breaks --help output)
* Wed Dec 13 2006 lmichnovic@suse.cz
- fixed string comparing (*strcmp.patch)
* Fri Jul 14 2006 lmichnovic@suse.cz
- update to version 3.60
  - non beta version
* Fri Jul 14 2006 lmichnovic@suse.cz
- update to version 3.60 beta 7
  - in unrar changed only version, version changed due to fix in rar
* Mon Jul 10 2006 lmichnovic@suse.cz
- upgrade to version 3.60 beta 6
  - no changelog available
* Wed Jun 21 2006 lmichnovic@suse.cz
- upgrade to version 3.60 beta 5
  - no changelog available
* Tue Jun 13 2006 lmichnovic@suse.cz
- upgrade to version 3.6.4
  - no changelog available
- change the numbering to 3.6.0.4 because it is 3.60 beta 4
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 schwab@suse.de
- Don't strip binaries.
* Thu Jan 12 2006 lmichnovic@suse.cz
- added -fstack-protector into CXXFLAGS
* Mon Nov 21 2005 lmichnovic@suse.cz
- added no-strict-aliasing option for compiling
* Tue Oct 11 2005 lmichnovic@suse.cz
- update to version 3.5.4
* Fri Sep 16 2005 lmichnovic@suse.cz
- update to version 3.5.3
* Tue Aug  2 2005 mjancar@suse.cz
- update ro 3.5.2
* Tue Apr 19 2005 mjancar@suse.cz
- fix for gcc 4.0
* Thu Feb 17 2005 mjancar@suse.cz
- update to 3.4.3
* Fri Aug  6 2004 mjancar@suse.cz
- update to 3.4.2
* Fri Feb 27 2004 mjancar@suse.cz
- update to 3.3.6
* Tue Oct 21 2003 mjancar@suse.cz
- update to 3.2.3
* Thu Jul 24 2003 mjancar@suse.cz
- update to 3.2.2
* Wed May 14 2003 mjancar@suse.cz
- update to version 3.2.1
* Tue May  6 2003 ro@suse.de
- fix build with latest gcc
* Mon Feb 17 2003 vbobek@suse.cz
- updated to version 3.1.3
- removed obsolete patch for CFLAGS
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue May 21 2002 nadvornik@suse.cz
- updated to 3.00 [bug #16183]
* Thu Apr 18 2002 stepan@suse.de
- update to 2.71, drop 64bit patch
* Wed Feb 20 2002 stepan@suse.de
- Fix archive corruption on 64bit systems. Linux GNU systems
  always have 32bit int, so using int instead of long for
  UDWORD.
* Mon Apr 17 2000 nadvornik@suse.cz
- added BuildRoot
* Thu Feb 17 2000 grimmer@suse.de
- use full URL to source archive
- use version macro
- spec file cleanups
- added Group tag
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Jul  5 1999 grimmer@suse.de
- initial package created (Version 2.50)
